The function calls one of the following functions:
plotEstimator(), plotGOF(), plotMCMCtrace(),
plotQALE(), plotQVI()
Arguments
- object
An object of class
SPQR.- output
A character indicating the type of plot to be returned.
"GOF": goodness of fit test by comparing the quantiles of probability integral transform (PIT) to that of uniform distribution."estimator": visualization of various estimates, including probability density function (PDF), cumulative density function (CDF) and quantile function (QF)."trace": diagnostic trace plots for SPQR fitted withmethod = "MCMC"."QALE": quantile accumulative local effects (ALE) for visualizing covariate effects on predicted quantiles."QVI": quantile variable importance comparison.
- ...
arguments passed into specific plot function, see
plotEstimator(),plotGOF(),plotMCMCtrace(),plotQALE()orplotQVI()for required arguments.