Computes and plots the estimated PDF/CDF/QF curves.
Arguments
- object
An object of class
"SPQR"- X
A row vector indicating covariate values for which the conditional PDF/CDF/QF is computed and plotted.
- ...
Arguments passed on to
predict.SPQRnYAn integer number indicating length of grid when
Yis not specified. Default: 101.typeThe function to be predicted;
"PDF": probability density function,"CDF": cumulative distribution function, and"QF": the quantile function (default).tauThe grid of quantiles for which the quantile function is computed. Default:
seq(0.1,0.9,0.1).ci.levelThe credible level for computing the pointwise credible intervals. The default is 0 indicating no credible intervals should be computed.
getAllIf
TRUE, extracts all posterior samples of the prediction. Default:FALSE.